==> web-glue-3.0-b34-sources.jar: com/sun/enterprise/web/connector/coyote/PECoyoteResponse.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.web.connector.coyote;

import java.util.logging.Logger;
import javax.servlet.http.Cookie;
import org.apache.catalina.connector.CoyoteWriter;
import org.apache.catalina.connector.Response;
import org.apache.catalina.connector.OutputBuffer;
import com.sun.enterprise.web.pwc.PwcWebModule;
import com.sun.enterprise.web.logging.pwc.LogDomains;

/**
 * Customized version of the Tomcat 5 CoyoteResponse
 */
public class PECoyoteResponse extends Response {

    private static final Logger logger = LogDomains.getLogger(PECoyoteResponse.class, LogDomains.PWC_LOGGER);

    /*
     * Constructor.
     */
    public PECoyoteResponse(boolean chunkingDisabled) {
	super(chunkingDisabled);
    }

    @Override
    protected CoyoteWriter createWriter(OutputBuffer outbuf) {
        return new PECoyoteWriter(outbuf);
    }

    // START GlassFish 898
    /**
     * Gets the string representation of the given cookie.
     *
     * @param cookie The cookie whose string representation to get
     *
     * @return The cookie's string representation
     */
    /*protected String getCookieString(Cookie cookie) {

        PwcWebModule wm = (PwcWebModule) getContext();
        boolean encodeCookies = false;
        if (wm != null && wm.getEncodeCookies()) {
            encodeCookies = true;
        }

        return getCookieString(cookie, encodeCookies);
    }*/
    // END GlassFish 898

    static class PECoyoteWriter
                    extends org.apache.catalina.connector.CoyoteWriter
                    implements org.glassfish.jsp.api.ByteWriter {

        public PECoyoteWriter(OutputBuffer ob) {
            super(ob);
        }
    }
}

==> web-glue-3.1-b12-sources.jar: com/sun/enterprise/web/connector/coyote/PECoyoteResponse.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2010 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */

package com.sun.enterprise.web.connector.coyote;

import com.sun.logging.LogDomains;
import org.apache.catalina.connector.CoyoteWriter;
import org.apache.catalina.connector.OutputBuffer;
import org.apache.catalina.connector.Response;

import java.util.logging.Logger;

/**
 * Customized version of the Tomcat 5 CoyoteResponse
 */
public class PECoyoteResponse extends Response {

    private static final Logger logger = LogDomains.getLogger(
        PECoyoteResponse.class, LogDomains.WEB_LOGGER);

    /*
     * Constructor.
     */
    public PECoyoteResponse(boolean chunkingDisabled) {
	super(chunkingDisabled);
    }

    @Override
    protected CoyoteWriter createWriter(OutputBuffer outbuf) {
        return new PECoyoteWriter(outbuf);
    }

    // START GlassFish 898
    /**
     * Gets the string representation of the given cookie.
     *
     * @param cookie The cookie whose string representation to get
     *
     * @return The cookie's string representation
     */
    /*protected String getCookieString(Cookie cookie) {

        PwcWebModule wm = (PwcWebModule) getContext();
        boolean encodeCookies = false;
        if (wm != null && wm.getEncodeCookies()) {
            encodeCookies = true;
        }

        return getCookieString(cookie, encodeCookies);
    }*/
    // END GlassFish 898

    static class PECoyoteWriter
                    extends org.apache.catalina.connector.CoyoteWriter
                    implements org.glassfish.jsp.api.ByteWriter {

        public PECoyoteWriter(OutputBuffer ob) {
            super(ob);
        }
    }
}
